Crate kcr_kubean_io

Crate kcr_kubean_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kubean.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

kubean.io/v1alpha1

  • ClusterOperation
  • Cluster
  • LocalArtifactSet
  • Manifest

Modules

v1alpha1